function M = load_shape(prefix, params)

fprintf('Loading mesh %s... ', prefix);

% change with your own loader if you work with other formats.
M = load_off(strcat(prefix,'.off'));

M.n = size(M.VERT,1);
M.m = size(M.TRIV,1);

if ~exist(strcat(prefix,'.evecs.dat'), 'file')
    
    % check for outlier vertices
    missing = setdiff(1:size(M.VERT,1), unique(M.TRIV(:)));
    is_outlier = false(size(M.VERT,1),1);
    is_outlier(missing) = true;
    if sum(is_outlier)>0
        error('The shape has outlier vertices. Run remove_vertices() and re-save the shape before proceeding (check commented code in load_shape()).');
        %M = remove_vertices(M, is_outlier);
        %save_as_off(strcat(prefix, '-clean.off'), M);
    end
    
    [M.evecs, M.evals, M.S, M.C] = calc_LB(M, params.n_eigen);
    v = M.evecs';
    save(strcat(prefix,'.evecs.dat'), 'v', '-ascii');
    v = [M.n ; M.evals];
    save(strcat(prefix,'.evals.dat'), 'v', '-ascii');
    v = full(diag(M.S));
    save(strcat(prefix,'.areas.dat'), 'v', '-ascii');
    v = M.C;
    save(strcat(prefix,'.cotans.mat'), 'v');
    
elseif nargout==1
    
    M.evals = load(strcat(prefix,'.evals.dat'));
    M.evals = M.evals(2:end);
    
    if length(M.evals)~=params.n_eigen
        error('The loaded eigen-decomposition has k=%d basis functions, but k=%d is specified in the parameters. Delete the temporary files and re-run the code if you want k=%d.', length(M.evals), params.n_eigen, params.n_eigen);
    end
    
    M.evecs = load(strcat(prefix,'.evecs.dat'));
    M.evecs = M.evecs';
    M.S = load(strcat(prefix,'.areas.dat'));
    M.S = sparse(1:M.n, 1:M.n, M.S);
    M.C = load(strcat(prefix,'.cotans.mat'));
    M.C = M.C.v;
    
end

fprintf('done.\n');

end
